怪兽电力公司 (豆瓣)
Description: 怪兽电力公司电影简介和剧情介绍,怪兽电力公司影评、图片、预告片、影讯、论坛、在线购票
Keywords: 怪兽电力公司,Monsters, Inc.,怪兽电力公司影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.133豆瓣电影Top250

# 怪兽电力公司 Monsters, Inc. (2001)

导演: 彼特·道格特 / 大卫·西尔弗曼 / 李·昂克里奇
编剧: 安德鲁·斯坦顿 / 丹尼尔·吉尔森 / 罗伯特·L·贝尔德 / 瑞特·里斯 / 乔纳森·罗伯特 / 彼特·道格特 / 杰夫·皮金 / 吉尔·卡尔顿 / 拉夫·埃格尔斯顿
主演: 约翰·古德曼 / 比利·克里斯托 / 玛丽·吉布斯 / 史蒂夫·布西密 / 詹姆斯·柯本 / 詹妮弗·提莉 / 鲍勃·彼德森 / 约翰·拉岑贝格 / 弗兰克·奥兹 / 丹尼尔·吉尔森 / 邦尼·亨特 / 杰克·安杰尔 / 塞缪尔·洛德·布莱克 / 史蒂夫·萨斯坎德
类型: 喜剧 / 动画 / 儿童 / 奇幻 / 冒险
官方网站: www.monstersinc.com
制片国家/地区: 美国
语言: 英语
上映日期: 2001-11-02(美国) / 2012-12-19(美国)
片长: 92分钟
又名: 怪兽公司(港) / 怪物公司
IMDb: tt0198781
豆瓣评分
引用
8.8
632330人评价
5星
48.6%
4星
41.6%
3星
9.4%
2星
0.4%
1星
0.1%
好于 97% 动画片
好于 98% 喜剧片
想看 看过
评价:
推荐

## 怪兽电力公司的剧情简介 · · · · · ·

我们不知道，在那样的世界里住着那样一群怪物。他们长相滑稽，却必须装作狰狞。因为，在夜深的时候，他们要悄悄的出现在孩子的衣橱里，吓唬刚刚甜美睡去的宝宝。一切，只因为他们是怪物电力公司的员工，而孩子的尖叫，则是怪物王国发电的全部能量。怪物们害怕孩子，却又必须让孩子尖叫。在怪物的国度里，他们都是为全民造福的英雄。
毛怪苏利文（约翰•古德曼）是怪物公司最出色的员工，业绩总是摇摇领先，他吓哭的小孩儿不计其数。他与搭档大眼怪麦克（比利•克里斯托）很受大家的爱戴。一次偶然，毛怪不小心把一个两岁的小女孩阿布（玛丽•吉布斯）带回了怪物世界，引起了极大的恐慌，调皮可爱的阿布把这些可怕的怪物吓的人仰马翻。警方在追捕阿布，而坏蛋亨利（詹姆斯•柯博）也计划利用阿布进行他改革工厂的邪恶计划。
另一方面，在与阿布相处的过程中，毛怪渐渐对她产生莫名的情愫，甚至因此被放逐野外。可是一... (展开全部) 我们不知道，在那样的世界里住着那样一群怪物。他们长相滑稽，却必须装作狰狞。因为，在夜深的时候，他们要悄悄的出现在孩子的衣橱里，吓唬刚刚甜美睡去的宝宝。一切，只因为他们是怪物电力公司的员工，而孩子的尖叫，则是怪物王国发电的全部能量。怪物们害怕孩子，却又必须让孩子尖叫。在怪物的国度里，他们都是为全民造福的英雄。
毛怪苏利文（约翰•古德曼）是怪物公司最出色的员工，业绩总是摇摇领先，他吓哭的小孩儿不计其数。他与搭档大眼怪麦克（比利•克里斯托）很受大家的爱戴。一次偶然，毛怪不小心把一个两岁的小女孩阿布（玛丽•吉布斯）带回了怪物世界，引起了极大的恐慌，调皮可爱的阿布把这些可怕的怪物吓的人仰马翻。警方在追捕阿布，而坏蛋亨利（詹姆斯•柯博）也计划利用阿布进行他改革工厂的邪恶计划。
另一方面，在与阿布相处的过程中，毛怪渐渐对她产生莫名的情愫，甚至因此被放逐野外。可是一切都不能抵挡毛怪拯救女孩的信念，为了阿布，毛怪踏上了艰险的旅程…… ©豆瓣

## 怪兽电力公司的演职员 · · · · · · ( 全部 54 )

- 彼特·道格特 导演
- 大卫·西尔弗曼 Co-director
- 约翰·古德曼 配 Sullivan
- 比利·克里斯托 配 Mike
- 玛丽·吉布斯 配 Boo
- 史蒂夫·布西密 配 Randall

## 怪兽电力公司的视频和图片 · · · · · · ( 预告片5 | 添加视频评论 | 图片578 · 添加 )

## 怪兽电力公司的获奖情况 · · · · · · ( 全部 )

- 第74届奥斯卡金像奖
- 最佳动画长片(提名)
- 约翰·拉塞特 / 彼特·道格特

- 第30届动画安妮奖
- 最佳动画长片(提名)

- 第27届报知映画赏
- 海外作品奖
- 彼特·道格特

## 喜欢这部电影的人也喜欢 · · · · · ·

  玩具总动员

  大闹天宫

  天空之城

  幽灵公主

  哈尔的移动城堡

  冰川时代

  哪吒闹海

  神偷奶爸

  风之谷

  美食总动员

我要写短评

## 怪兽电力公司的短评 · · · · · · ( 全部 81666 条 )

热门 / 最新 / 好友

### 1474 有用 影志 看过 2006-01-08 05:01:51

"不要给它起名字，起了名字就有感情了"，不管是什么物种，它们的情感在皮克斯手笔下永远都是那么细腻，看到毛怪对小阿布告别时说：“Go ahead, Go grow up...” 眼珠各种打滚。《WALL·E》之外最爱的一部Pixar动画长片。We scare, because we care.

### 1631 有用 战国客 看过 2007-06-24 10:37:28

简直就是最爱啊！编剧太可爱了,居然能想到用孩子的哭声和笑声作为电力能源。什么叫创意?这就叫创意~~

### 1474 有用 泪小鱼|念。 看过 2007-02-06 12:03:45

那一声KITTY，软了我的眼泪。

### 2413 有用 猫猫 看过 2012-03-30 16:55:47

其实我觉得。。。这片是一对gay couple养孩子的故事。。。

### 927 有用 薇羅尼卡 看过 2006-01-08 23:16:08

不要以外表来判断一个人的心，宝贝，永远都不要。

> 更多短评 81666条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 怪兽电力公司的影评 · · · · · · ( 全部 380 条 )

热门 / 最新 / 好友
Aii 2007-11-09 15:01:58

## 我说你就是经典

最近《料理鼠王》非常的火，大家对之剧情也是褒贬不一，但对于皮克斯的技术都是无一例外的赞叹不已，他们提到小老鼠清晰逼真的毛发时总提到《怪物公司》，确实很久前的这部片子已经在当时掀起了相当的轰动，简直成为当时3D动画界无法超越的顶峰。 最近回家把这部片子认真... (展开)
237 23 39回应 收起
清心咒 2006-01-23 13:43:31

## grow up

一路欢笑，但当分别的时候来临，麦克对阿布说，go,go to grow up,我的眼泪就这样流下来，人总是这样，无情地长大。 (展开)
133 6 12回应 收起
orang2e 2006-01-30 03:45:29

## 给它起个名字吧

麦克说，不要给它起名字，起了名字就有感情了。 我看了看身边熟睡的贝贝，看着它的小肚子因为均匀的呼吸一起一伏…… 好像真的是这样哦：） 我们为什么要把生命分为这么多种呢？ 我们只要用一颗善良的心去疼爱它们就好了。 给它起一个名字，它不一定就是你的，可是你就可以去... (展开)
60 3 9回应 收起
momo 2017-05-09 20:04:37

## 怪兽电力公司

孩子们的哭声可以制作电能？感觉这个点很有创造力呢。 于是有一个怪物公司，专门去吓唬孩子，孩子们最怕的就是主角萨利。 孩子们怕怪兽，怪兽怕孩子们。。。两个生物碰撞出了不同的火花。。。然而，现在的孩子们并不是那么容易被吓到的。。。来自人类世界的阿布的女孩子，把... (展开)
27 0回应 收起
傅踢踢 2008-07-29 22:20:26

## 我隶属怪兽电力公司，这是我的故事

苏利文的故事 我在一只眼睛比脚还富余的类螃蟹手下打工，无论在一眼、多眼还是红毛、绿毛怪物的心里，我是当之无愧的业务明星。当然，除了那只叫兰道的变色龙。 我的伙计华斯基也是我的助手。他每天的工作就是不断上交报表、报表，像是一家跨国咨询公司的业务员。然而，他每... (展开)
48 14 15回应 收起
叶不羞的嘲讽脸 2017-08-23 23:45:53

## 笑声战胜哭声

画风如此氢气，用尖叫声来发电，这个创意绝了，而且反转让人出乎意料！ 毛怪和独眼这对也是反差萌的好基友！ 直到阿布的出现，一切慢慢发生改变！ 这些吓人的怪物一边吓人一边又害怕，他们不能沾染人类的东西，，这是毛怪一开始想把阿布送回去的原因！可是在这个过程中，毛怪对... (展开)
29 3 0回应 收起
考不上不换昵称 2017-06-04 17:37:24

## 故事情节奇妙的起承转合，悬念迭起

这篇影评可能有剧透

《怪兽电力公司》是一部非常赞的影片，美国的动漫电影总是传达了很强的正能量。一部动画片，说的是怪物，反映的却是人类社会的现状。贪得无厌的人类对资源的攫取，永远都未曾停歇。牺牲其他物种来获取资源，这种勾当又是多么的令人唾弃！幸好，当长毛怪苏利文掌管电力公司后，... (展开)
24 0回应 收起
轻寻到下绿 2017-07-28 19:09:05

## 纯粹的感动

编剧超级有想象力，居然能想到用孩子的哭声作为电力能量。 毛怪最后灵感一闪，把电力公司改造成收集笑声的工厂，原来整装待发去吓唬人的怪兽们，都使出浑身解数去逗小孩子们发笑，很有爱的画面啊！ 这是一部在今日看来特效依旧那般值得称赞的光影童话，《怪兽电力公司》极富想... (展开)
24 2回应 收起
你不惹我不惹你 2017-05-19 14:43:09

## 怪兽的世界

这剧《怪兽的电力公司》我们一直以为躲在门后的怪兽是来吓人的。事实上，那些怪兽是来上班的。因为小孩的尖叫声是怪兽世界的主要能源，所以“怪兽电力公司”的怪兽们每天的工作就是透过衣橱的门进入人类世界去吓小孩，收集他们的尖叫声，并带回“怪兽电力公司”转换成能源。另... (展开)
13 2 0回应 收起

> 更多影评 380篇

添加新讨论

## 讨论区 · · · · · ·

这里面小孩长得真恐怖 | 来自德拉克萨的暮刃 | 7 回应 | 2022-11-11 22:28:31
最后门是怎么拼起来的？不是都用粉碎机粉碎成末了吗？ | 来自韩大狗打个蛋 | 7 回应 | 2022-10-14 22:45:47
好看 | 来自ncrmep |  | 2022-10-04 20:57:48
我心中的影史最好的动画片，没有之一。 | 来自阿堵物 | 47 回应 | 2022-08-31 18:53:32
为什么要说小朋友有毒 | 来自小猫咪喵喵喵 | 4 回应 | 2022-08-18 23:44:11

> 去这部影片的讨论区（全部115条）

## 关于《怪兽电力公司》的问题 · · · · · · ( 全部6个 )

- 有几处地方没看懂,怪兽电力公司里面门的问题？ 2人回答
- 小布明明已经要被蓝道发现了，最后都因为其他人影响逃掉了。。。这些画面有什么深层意义？ 1人回答

> 全部6个问题

## 在哪儿看这部电影 · · · · · ·

- 咪咕视频 VIP免费观看
- 腾讯视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- 【内牛满面】 (影志)
- 【豆瓣高分动画长片】 (影志)
- 那些牛叉闪闪的片子 (家庭种菜笔记)
- {北美电影票房总排行} (荔枝超人)
- 【爱看动画】 (影志)

## 谁在看这部电影 · · · · · ·

- whcwhcwhc
  2分钟前 看过
- Cloris雷菁
  6分钟前 看过
- 锦书誰寄
  14分钟前 看过

1082010人看过 / 149472人想看

订阅怪兽电力公司的评论:
feed: rss 2.0